GLOBAL_DATA = '{}/all'
ALL_COUNTRIES = '{}/countries'
SORTED_COUNTRIES = '{}/countries?sort={}'
COUNTRY_DATA = '{}/countries/{}'
ALL_STATES = '{}/states'
SINGLE_STATE = '{}/states/{}'
HISTORICAL_COUNTRY = '{}/v2/historical/{}?lastdays={}'
HISTORICAL_PROVINCE = '{}/v2/historical/{}/{}?lastdays={}'
JHU_CSSE = '{}/v2/jhucsse'
JHU_CSSE_COUNTIES = '{}/v2/jhucsse/counties/{}'
YESTERDAY = '{}/yesterday'